==> digiRhythm_1.1.tar.gz: digiRhythm/R/data.R <==
#' df516b_2 Activity Data Sets
#'
#' A dataset containing the Motion index and steps count of a cow.
#' The data set is sampled with 15 minutes samples. The data is as follows:
#'
#' @format A data frame of 3 columns
#' \describe{
#'  \item{datetime}{a POSIX formatted datetime}
#'  \item{Motion.Index}{The motion index of the cow during the time sample}
#'  \item{Steps}{The number of steps during the time sample}
#' }
#'
#' @source Agroscope Tanikon
"df516b_2"

#' df678_2 Activity Data Sets
#'
#' A dataset containing the Motion index and steps count of a cow.
#' The data set is sampled with 15 minutes samples. The data is as follows:
#'
#' @format A data frame of 3 columns
#' \describe{
#'  \item{datetime}{a POSIX formatted datetime}
#'  \item{Motion.Index}{The motion index of the cow during the time sample}
#'  \item{Steps}{The number of steps during the time sample}
#' }
#'
#' @source Agroscope Tanikon
"df678_2"

#' df689b_3 Activity Data Sets
#'
#' A dataset containing the Motion index and steps count of a cow.
#' The data set is sampled with 15 minutes samples. The data is as follows:
#'
#' @format A data frame of 3 columns
#' \describe{
#'  \item{datetime}{a POSIX formatted datetime}
#'  \item{Motion.Index}{The motion index of the cow during the time sample}
#'  \item{Steps}{The number of steps during the time sample}
#' }
#'
#' @source Agroscope Tanikon
"df689b_3"

#' df691b_1 Activity Data Sets
#'
#' A dataset containing the Motion index and steps count of a cow.
#' The data set is sampled with 15 minutes samples. The data is as follows:
#'
#' @format A data frame of 3 columns
#' \describe{
#'  \item{datetime}{a POSIX formatted datetime}
#'  \item{Motion.Index}{The motion index of the cow during the time sample}
#'  \item{Steps}{The number of steps during the time sample}
#' }
#'
#' @source Agroscope Tanikon
"df691b_1"

#' df759a_3 Activity Data Sets
#'
#' A dataset containing the Motion index and steps count of a cow.
#' The data set is sampled with 15 minutes samples. The data is as follows:
#'
#' @format A data frame of 3 columns
#' \describe{
#'  \item{datetime}{a POSIX formatted datetime}
#'  \item{Motion.Index}{The motion index of the cow during the time sample}
#'  \item{Steps}{The number of steps during the time sample}
#' }
#'
#' @source Agroscope Tanikon
"df759a_3"


#' df603 Activity Data Sets
#'
#' A dataset containing the x and y acceleration from an accelerometer installed
#' on a cattle. There are missing days in this dataset.
#' The data set is sampled with 15 minutes samples. The data is as follows:
#'
#' @format A data frame of 3 columns
#' \describe{
#'  \item{datetime}{a POSIX formatted datetime}
#'  \item{move_x}{The acceleration along the x axis}
#'  \item{move_y}{The acceleration along the y axis}
#' }
#'
#' @source Agroscope Posieux
"df603"


#' df625 Activity Data Sets
#'
#' A dataset containing the x and y acceleration from an accelerometer installed
#' on a cattle. There are missing days in this dataset.
#' The data set is sampled with 15 minutes samples. The data is as follows:
#'
#' @format A data frame of 3 columns
#' \describe{
#'  \item{datetime}{a POSIX formatted datetime}
#'  \item{move_x}{The acceleration along the x axis}
#'  \item{move_y}{The acceleration along the y axis}
#' }
#'
#' @source Agroscope Posieux
"df625"

==> digiRhythm_2.0.tar.gz: digiRhythm/R/data.R <==
#' df516b_2 Activity Data Sets
#'
#' A dataset containing the Motion index and steps count of a cow.
#' The data set is sampled with 15 minutes samples. The data is as follows:
#'
#' @format A data frame of 3 columns
#' \describe{
#'  \item{datetime}{a POSIX formatted datetime}
#'  \item{Motion.Index}{The motion index of the cow during the time sample}
#'  \item{Steps}{The number of steps during the time sample}
#' }
#'
#' @source Agroscope Tanikon
"df516b_2"

#' df678_2 Activity Data Sets
#'
#' A dataset containing the Motion index and steps count of a cow.
#' The data set is sampled with 15 minutes samples. The data is as follows:
#'
#' @format A data frame of 3 columns
#' \describe{
#'  \item{datetime}{a POSIX formatted datetime}
#'  \item{Motion.Index}{The motion index of the cow during the time sample}
#'  \item{Steps}{The number of steps during the time sample}
#' }
#'
#' @source Agroscope Tanikon
"df678_2"

#' df689b_3 Activity Data Sets
#'
#' A dataset containing the Motion index and steps count of a cow.
#' The data set is sampled with 15 minutes samples. The data is as follows:
#'
#' @format A data frame of 3 columns
#' \describe{
#'  \item{datetime}{a POSIX formatted datetime}
#'  \item{Motion.Index}{The motion index of the cow during the time sample}
#'  \item{Steps}{The number of steps during the time sample}
#' }
#'
#' @source Agroscope Tanikon
"df689b_3"

#' df691b_1 Activity Data Sets
#'
#' A dataset containing the Motion index and steps count of a cow.
#' The data set is sampled with 15 minutes samples. The data is as follows:
#'
#' @format A data frame of 3 columns
#' \describe{
#'  \item{datetime}{a POSIX formatted datetime}
#'  \item{Motion.Index}{The motion index of the cow during the time sample}
#'  \item{Steps}{The number of steps during the time sample}
#' }
#'
#' @source Agroscope Tanikon
"df691b_1"

#' df759a_3 Activity Data Sets
#'
#' A dataset containing the Motion index and steps count of a cow.
#' The data set is sampled with 15 minutes samples. The data is as follows:
#'
#' @format A data frame of 3 columns
#' \describe{
#'  \item{datetime}{a POSIX formatted datetime}
#'  \item{Motion.Index}{The motion index of the cow during the time sample}
#'  \item{Steps}{The number of steps during the time sample}
#' }
#'
#' @source Agroscope Tanikon
"df759a_3"


#' df603 Activity Data Sets
#'
#' A dataset containing the x and y acceleration from an accelerometer installed
#' on a cattle. There are missing days in this dataset.
#' The data set is sampled with 15 minutes samples. The data is as follows:
#'
#' @format A data frame of 3 columns
#' \describe{
#'  \item{datetime}{a POSIX formatted datetime}
#'  \item{move_x}{The acceleration along the x axis}
#'  \item{move_y}{The acceleration along the y axis}
#' }
#'
#' @source Agroscope Posieux
"df603"


#' df625 Activity Data Sets
#'
#' A dataset containing the x and y acceleration from an accelerometer installed
#' on a cattle. There are missing days in this dataset.
#' The data set is sampled with 15 minutes samples. The data is as follows:
#'
#' @format A data frame of 3 columns
#' \describe{
#'  \item{datetime}{a POSIX formatted datetime}
#'  \item{move_x}{The acceleration along the x axis}
#'  \item{move_y}{The acceleration along the y axis}
#' }
#'
#' @source Agroscope Posieux
"df625"


#' timedata Dataset of start and end of day and night
#'
#' A dataset of start and endtime of the morningmilking and eveningmilking on a dairy farm.
#'
#' @format A data frame of 4 columns
#' \describe{
#'  \item{day_start}{a POSIX formatted datetime}
#'  \item{day_end}{a POSIX formatted datetime}
#'  \item{night_start}{a POSIX formatted datetime}
#'  \item{night_end}{a POSIX formatted datetime}
#' }
#'
#' @source Johann Heinrich von Thünen- Institute of Organic Farming
"timedata"
